veloxml.svm package
===================

Submodules
----------

veloxml.svm.svm\_classification module
--------------------------------------

.. automodule:: veloxml.svm.svm_classification
   :members:
   :show-inheritance:
   :undoc-members:

Module contents
---------------

.. automodule:: veloxml.svm
   :members:
   :show-inheritance:
   :undoc-members:
